@@ -9,7 +9,7 @@
 #                                                                            #
 #----------------------------------------------------------------------------#
 #
-# $Id: xymonclient-linux.sh 7059 2012-07-14 15:18:14Z storner $
+# $Id: xymonclient-linux.sh 7362 2014-01-23 20:42:41Z storner $
 
 echo "[date]"
 date
@@ -18,10 +18,10 @@ uname -rsmn
 echo "[osversion]"
 if [ -x /bin/lsb_release ]; then
 	/bin/lsb_release -r -i -s | xargs echo
-	/bin/lsb_release -a
+	/bin/lsb_release -a 2>/dev/null
 elif [ -x /usr/bin/lsb_release ]; then
 	/usr/bin/lsb_release -r -i -s | xargs echo
-	/usr/bin/lsb_release -a
+	/usr/bin/lsb_release -a 2>/dev/null
 elif [ -f /etc/redhat-release ]; then
 	cat /etc/redhat-release
 elif [ -f /etc/gentoo-release ]; then
@@ -45,22 +45,23 @@ uptime
 echo "[who]"
 who
 echo "[df]"
-EXCLUDES=`cat /proc/filesystems | grep nodev | awk '{print $2}' | xargs echo | sed -e 's! ! -x !g'`
+EXCLUDES=`cat /proc/filesystems | grep nodev | grep -v rootfs | awk '{print $2}' | xargs echo | sed -e 's! ! -x !g'`
+ROOTFS=`readlink -m /dev/root`
 df -Pl -x iso9660 -x $EXCLUDES | sed -e '/^[^ 	][^ 	]*$/{
 N
 s/[ 	]*\n[ 	]*/ /
-}'
+}' -e "s&^rootfs&${ROOTFS}&"
 echo "[inode]"
 df -Pil -x iso9660 -x $EXCLUDES | sed -e '/^[^ 	][^ 	]*$/{
 N
 s/[ 	]*\n[ 	]*/ /
-}'
+}' -e "s&^rootfs&${ROOTFS}&"
 echo "[mount]"
 mount
 echo "[free]"
 free
 echo "[ifconfig]"
-/sbin/ifconfig
+/sbin/ifconfig 2>/dev/null
 echo "[route]"
 netstat -rn
 echo "[netstat]"
@@ -69,11 +70,11 @@ echo "[ports]"
 # Bug in RedHat's netstat spews annoying error messages. 
 netstat -ant 2>/dev/null
 echo "[ifstat]"
-/sbin/ifconfig
+/sbin/ifconfig 2>/dev/null
 # Report mdstat data if it exists
 if test -r /proc/mdstat; then echo "[mdstat]"; cat /proc/mdstat; fi
 echo "[ps]"
-ps -Aww -o pid,ppid,user,start,state,pri,pcpu,time,pmem,rsz,vsz,cmd
+ps -Aww -o pid,ppid,user,start,state,pri,pcpu,time:12,pmem,rsz:10,vsz:10,cmd
 
 # $TOP must be set, the install utility should do that for us if it exists.
 if test "$TOP" != ""
@@ -82,6 +83,8 @@ then
     then
         echo "[top]"
 	$TOP -b -n 1 
+	# Some top versions do not finish off the last line of output
+	echo ""
     fi
 fi
 
