@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: availability.c 6712 2011-07-31 21:01:52Z storner $";
+static char rcsid[] = "$Id: availability.c 7085 2012-07-16 11:08:37Z storner $";
 
 #include <limits.h>
 #include <stdio.h>
@@ -301,7 +301,7 @@ static int scan_historyfile(FILE *fd, time_t fromtime, time_t totime,
 
 				if ((start + dur) < fromtime) {
 					fseeko(fd, 2048, SEEK_CUR);
-					fgets(buf, bufsize, fd); /* Skip partial line */
+					if (!fgets(buf, bufsize, fd)) {}; /* Skip partial line */
 				}
 			}
 		}
@@ -316,7 +316,7 @@ static int scan_historyfile(FILE *fd, time_t fromtime, time_t totime,
 		rewind(fd);
 	else {
 		fseeko(fd, -2300, SEEK_CUR); 
-		fgets(buf, bufsize, fd); /* Skip partial line */
+		if (!fgets(buf, bufsize, fd)) {}; /* Skip partial line */
 	}
 
 	/* Read one line at a time until we hit start of our report period */
@@ -553,7 +553,6 @@ void restore_replogs(replog_t *head)
 
 int history_color(FILE *fd, time_t snapshot, time_t *starttime, char **histlogname)
 {
-	int fileerrors;
 	char l[MAX_LINE_LEN];
 	time_t duration;
 	char colstr[MAX_LINE_LEN];
@@ -561,8 +560,7 @@ int history_color(FILE *fd, time_t snapshot, time_t *starttime, char **histlogna
 	char *p;
 
 	*histlogname = NULL;
-	fileerrors = scan_historyfile(fd, snapshot, snapshot, 
-				      l, sizeof(l), starttime, &duration, colstr);
+	scan_historyfile(fd, snapshot, snapshot, l, sizeof(l), starttime, &duration, colstr);
 	
 	strcat(colstr, " ");
 	color = parse_color(colstr);
