@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: environ.c 7060 2012-07-14 16:32:11Z storner $";
+static char rcsid[] = "$Id: environ.c 7350 2014-01-19 12:17:56Z storner $";
 
 #include <ctype.h>
 #include <string.h>
@@ -36,7 +36,7 @@ const static struct {
 	{ "XYMONSERVERSECCGIURL", "/xymon-cgisecure" },
 	{ "XYMONNETWORK", "" },
 	{ "BBLOCATION", "" },
-	{ "PATH", "/bin:/usr/bin:/sbin:/usr/sbin:/usr/local/bin:/usr/local/sbin:"BUILD_HOME"/bin" },
+	{ "PATH", "/bin:/usr/bin:/sbin:/usr/sbin:/usr/local/bin:/usr/local/sbin:"XYMONHOME"/bin" },
 	{ "DELAYRED", "" },
 	{ "DELAYYELLOW", "" },
 	{ "XYMONDPORT", "1984" },
@@ -67,7 +67,7 @@ const static struct {
 	{ "XYMONSNAPURL", "$XYMONSERVERWWWURL/snap" },
 	{ "XYMONWAP", "$XYMONSERVERWWWURL/wml" },
 	{ "CGIBINURL", "$XYMONSERVERCGIURL" },
-	{ "XYMONHOME", BUILD_HOME },
+	{ "XYMONHOME", XYMONHOME },
 	{ "XYMONTMP", "$XYMONHOME/tmp" },
 	{ "HOSTSCFG", "$XYMONHOME/etc/hosts.cfg" },
 	{ "XYMON", "$XYMONHOME/bin/xymon" },
@@ -110,6 +110,7 @@ const static struct {
 	{ "XYMONNONGREENEXT", "eventlog.sh acklog.sh" },
 	{ "DOTHEIGHT", "16" },
 	{ "DOTWIDTH", "16" },
+	{ "IMAGEFILETYPE", "gif" },
 	{ "RRDHEIGHT", "120" },
 	{ "RRDWIDTH", "576" },
 	{ "COLUMNDOCURL", "$CGIBINURL/columndoc.sh?%s" },
