@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: headfoot.c 7085 2012-07-16 11:08:37Z storner $";
+static char rcsid[] = "$Id: headfoot.c 7435 2014-02-13 11:22:08Z storner $";
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -55,6 +55,8 @@ static char *pagepattern_text = NULL;
 static pcre *pagepattern = NULL;
 static char *ippattern_text = NULL;
 static pcre *ippattern = NULL;
+static char *classpattern_text = NULL;
+static pcre *classpattern = NULL;
 static void * hostnames;
 static void * testnames;
 
@@ -154,7 +156,7 @@ void sethostenv_pagepath(char *s)
 	hostenv_pagepath = strdup(s);
 }
 
-void sethostenv_filter(char *hostptn, char *pageptn, char *ipptn)
+void sethostenv_filter(char *hostptn, char *pageptn, char *ipptn, char *classptn)
 {
 	const char *errmsg;
 	int errofs;
@@ -165,6 +167,8 @@ void sethostenv_filter(char *hostptn, char *pageptn, char *ipptn)
 	if (pagepattern) { pcre_free(pagepattern); pagepattern = NULL; }
 	if (ippattern_text) xfree(ippattern_text);
 	if (ippattern) { pcre_free(ippattern); ippattern = NULL; }
+	if (classpattern_text) xfree(classpattern_text);
+	if (classpattern) { pcre_free(classpattern); classpattern = NULL; }
 
 	/* Setup the pattern to match names against */
 	if (hostptn) {
@@ -179,6 +183,10 @@ void sethostenv_filter(char *hostptn, char *pageptn, char *ipptn)
 		ippattern_text = strdup(ipptn);
 		ippattern = pcre_compile(ipptn, PCRE_CASELESS, &errmsg, &errofs, NULL);
 	}
+	if (classptn) {
+		classpattern_text = strdup(classptn);
+		classpattern = pcre_compile(classptn, PCRE_CASELESS, &errmsg, &errofs, NULL);
+	}
 }
 
 static listpool_t *find_listpool(char *listname)
@@ -387,6 +395,15 @@ static void *wanted_host(char *hostname)
 		if (result < 0) return NULL;
 	}
 
+	if (classpattern && hinfo) {
+		char *hostclass = xmh_item(hinfo, XMH_CLASS);
+		if (!hostclass) return NULL;
+
+		result = pcre_exec(classpattern, NULL, hostclass, strlen(hostclass), 0, 0,
+				ovector, (sizeof(ovector)/sizeof(int)));
+		if (result < 0) return NULL;
+	}
+
 	return hinfo;
 }
 
@@ -842,6 +859,9 @@ void output_parsed(FILE *output, char *templatedata, int bgcolor, time_t selecte
 		else if (strcmp(t_start, "IPFILTER") == 0) {
 			if (ippattern_text) fprintf(output, "%s", ippattern_text);
 		}
+		else if (strcmp(t_start, "CLASSFILTER") == 0) {
+			if (classpattern_text) fprintf(output, "%s", classpattern_text);
+		}
 		else if (strcmp(t_start, "HOSTLIST") == 0) {
 			xtreePos_t handle;
 			treerec_t *rec;
