@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: htmllog.c 6712 2011-07-31 21:01:52Z storner $";
+static char rcsid[] = "$Id: htmllog.c 7085 2012-07-16 11:08:37Z storner $";
 
 #include <ctype.h>
 #include <stdlib.h>
@@ -71,7 +71,6 @@ static void hostpopup_setup(void)
 static void hostsvc_setup(void)
 {
 	static int setup_done = 0;
-	char *dac;
 
 	if (setup_done) return;
 
@@ -209,11 +208,12 @@ void generate_html_log(char *hostname, char *displayname, char *service, char *i
 		if (formfile >= 0) {
 			char *inbuf;
 			struct stat st;
+			int n;
 
 			fstat(formfile, &st);
-			inbuf = (char *) malloc(st.st_size + 1);
-			read(formfile, inbuf, st.st_size);
-			inbuf[st.st_size] = '\0';
+			inbuf = (char *) malloc(st.st_size + 1); *inbuf = '\0';
+			n = read(formfile, inbuf, st.st_size);
+			if (n > 0) inbuf[n] = '\0';
 			close(formfile);
 
 			sethostenv_backsecs(graphtime);
@@ -232,11 +232,12 @@ void generate_html_log(char *hostname, char *displayname, char *service, char *i
 		if (formfile >= 0) {
 			char *inbuf;
 			struct stat st;
+			int n;
 
 			fstat(formfile, &st);
-			inbuf = (char *) malloc(st.st_size + 1);
-			read(formfile, inbuf, st.st_size);
-			inbuf[st.st_size] = '\0';
+			inbuf = (char *) malloc(st.st_size + 1); *inbuf = '\0';
+			n = read(formfile, inbuf, st.st_size);
+			if (n > 0) inbuf[st.st_size] = '\0';
 			close(formfile);
 
 			sethostenv_critack(atoi(prio), ttgroup, ttextra, 
