@@ -11,13 +11,14 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: strfunc.c 7038 2012-07-13 14:51:14Z storner $";
+static char rcsid[] = "$Id: strfunc.c 7390 2014-02-04 16:08:37Z storner $";
 
 #include "config.h"
 
 #include <ctype.h>
 #include <string.h>
 #include <stdlib.h>
+#include <stdarg.h>
 
 #include "libxymon.h"
 #include "version.h"
@@ -122,6 +123,20 @@ void addtobuffer(strbuffer_t *buf, char *newtext)
 	if (newtext) strbuf_addtobuffer(buf, newtext, strlen(newtext));
 }
 
+void addtobuffer_many(strbuffer_t *buf, ...)
+{
+	va_list ap;
+	char *newtext;
+
+	va_start(ap, buf);
+	newtext = va_arg(ap, char *);
+	while (newtext) {
+		strbuf_addtobuffer(buf, newtext, strlen(newtext));
+		newtext = va_arg(ap, char *);
+	}
+	va_end(ap);
+}
+
 void addtostrbuffer(strbuffer_t *buf, strbuffer_t *newtext)
 {
 	strbuf_addtobuffer(buf, STRBUF(newtext), STRBUFLEN(newtext));
@@ -188,6 +203,8 @@ char *htmlquoted(char *s)
 	char *inp, *endp;
 	char c;
 
+	if (!s) return NULL;
+
 	if (!result) result = newstrbuffer(4096);
 	clearstrbuffer(result);
 
