@@ -14,7 +14,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: acknowledge.c 6790 2011-12-06 12:56:24Z storner $";
+static char rcsid[] = "$Id: acknowledge.c 7381 2014-01-27 16:56:50Z storner $";
 
 #include <limits.h>
 #include <stdio.h>
@@ -247,11 +247,20 @@ int main(int argc, char *argv[])
 			char *hostname, *pagename;
 			int gotfilter = 0, filtererror = 0;
 			sendreturn_t *sres = NULL;
+			int col, firstcolor = 1, alertcolors = colorset(xgetenv("ALERTCOLORS"), ((1 << COL_GREEN) | (1 << COL_BLUE)));
 
 			headfoot(stdout, "acknowledge", "", "header", COL_RED);
 
 			cmd = (char *)malloc(1024);
-			strcpy(cmd, "xymondboard color=red,yellow fields=hostname,testname,cookie");
+			strcpy(cmd, "xymondboard fields=hostname,testname,cookie color=");
+			for (col = 0; (col < COL_COUNT); col++) {
+				if ((1 << col) & alertcolors) {
+					if (!firstcolor) strcat(cmd, ",");
+					strcat(cmd, colorname(col));
+					firstcolor = 0;
+				}
+			}
+			// printf("<!-- cmd = %s -->\n", cmd);
 
 			if (obeycookies && !gotfilter && ((hostname = get_cookie("host")) != NULL)) {
 				if (*hostname) {
@@ -329,7 +338,7 @@ int main(int argc, char *argv[])
 				}
 
 				if (first) {
-					fprintf(stdout, "<center><font size=\"+1\"><b>No active alerts</b></font></center\n");
+					fprintf(stdout, "<center><font size=\"+1\"><b>No active alerts</b></font></center>\n");
 				}
 				else {
 					generate_ackline(stdout, NULL, NULL, NULL);
