@@ -13,7 +13,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: do_alert.c 7117 2012-07-24 15:48:41Z storner $";
+static char rcsid[] = "$Id: do_alert.c 7380 2014-01-27 16:55:41Z storner $";
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -264,7 +264,7 @@ static char *message_text(activealerts_t *alert, recip_t *recip)
 	switch (recip->format) {
 	  case ALERTFORM_TEXT:
 	  case ALERTFORM_PLAIN:
-		bom = msg_data(alert->pagemessage);
+		bom = msg_data(alert->pagemessage, 1);
 		eoln = strchr(bom, '\n'); if (eoln) *eoln = '\0';
 
 		/* If there's a "<-- flags:.... -->" then remove it from the message */
@@ -332,7 +332,7 @@ static char *message_text(activealerts_t *alert, recip_t *recip)
 		}
 
 		addtobuffer(buf, info);
-		bom = msg_data(alert->pagemessage);
+		bom = msg_data(alert->pagemessage, 1);
 		eoln = strchr(bom, '\n');
 		if (eoln) {
 			bom = eoln;
@@ -351,7 +351,7 @@ static char *message_text(activealerts_t *alert, recip_t *recip)
 		sprintf(info, "%s:%s %s [%d]\n",
 			alert->hostname, alert->testname, colorname(alert->color), alert->cookie);
 		addtobuffer(buf, info);
-		addtobuffer(buf, msg_data(alert->pagemessage));
+		addtobuffer(buf, msg_data(alert->pagemessage, 0));
 		addtobuffer(buf, "\n");
 		sprintf(info, "See %s%s\n", 
 			xgetenv("XYMONWEBHOST"),
@@ -412,13 +412,18 @@ void send_alert(activealerts_t *alert, FILE *logfd)
 			rpt = find_repeatinfo(alert, recip, 1);
 			if (!rpt) continue;	/* Happens for e.g. M_IGNORE recipients */
 
+			/* 
+			 * Update alertcount here, because we dont want to hit an UNMATCHED
+			 * rule when there is actually an alert active - it is just suppressed
+			 * for this run due to the REPEAT setting.
+			 */
+			alertcount++;	
 			dbgprintf("  repeat %s at %d\n", rpt->recipid, rpt->nextalert);
 			if (rpt->nextalert > now) {
 				traceprintf("Recipient '%s' dropped, next alert due at %ld > %ld\n",
 						rpt->recipid, (long)rpt->nextalert, (long)now);
 				continue;
 			}
-			alertcount++;
 		}
 		else if ((alert->state == A_RECOVERED) || (alert->state == A_DISABLED)) {
 			/* RECOVERED messages require that we've sent out an alert before */
@@ -684,31 +689,42 @@ time_t next_alert(activealerts_t *alert)
 	recip_t *recip;
 	repeat_t *rpt;
 	time_t r_next = -1;
+	void *hinfo = hostinfo(alert->hostname);
 
 	stoprulefound = 0;
 	while (!stoprulefound && ((recip = next_recipient(alert, &first, NULL, &r_next)) != NULL)) {
 		found = 1;
-		/* 
-		 * This runs in the parent xymond_alert proces, so we must create
-		 * a repeat-record here - or all alerts will get repeated every minute.
-		 */
-		rpt = find_repeatinfo(alert, recip, 1);
-		if (rpt) {
-			if (rpt->nextalert <= now) rpt->nextalert = (now + recip->interval);
-			if (rpt->nextalert < nexttime) nexttime = rpt->nextalert;
-		}
-		else if (r_next != -1) {
-			if (r_next < nexttime) nexttime = r_next;
+
+		if (recip->criteria && recip->criteria->timespec && !timematch(xmh_item(hinfo, XMH_HOLIDAYS), recip->criteria->timespec)) {
+			/* Recipient not active due to time-restrictions. */
+			if ((r_next != -1) && (r_next < nexttime)) nexttime = r_next;
 		}
 		else {
 			/* 
-			 * This can happen, e.g.  if we get an alert, but the minimum 
-			 * DURATION has not been met.
-			 * This simply means we dropped the alert -for now - for some 
-			 * reason, so it should be retried again right away. Put in a
-			 * 1 minute delay to prevent run-away alerts from flooding us.
+			 * This runs in the parent xymond_alert proces, so we must create
+			 * a repeat-record here - or all alerts will get repeated every minute.
+			 * 
+			 * NB: Even though we say "create", find_repeatinfo() will return NULL
+			 *     for ignored alerts.
 			 */
-			if ((now + 60) < nexttime) nexttime = now + 60;
+			rpt = find_repeatinfo(alert, recip, 1);
+			if (rpt) {
+				if (rpt->nextalert <= now) rpt->nextalert = (now + recip->interval);
+				if (rpt->nextalert < nexttime) nexttime = rpt->nextalert;
+			}
+			else if (r_next != -1) {
+				if (r_next < nexttime) nexttime = r_next;
+			}
+			else {
+				/* 
+				 * This can happen, e.g.  if we get an alert, but the minimum 
+				 * DURATION has not been met.
+				 * This simply means we dropped the alert -for now - for some 
+				 * reason, so it should be retried again right away. Put in a
+				 * 1 minute delay to prevent run-away alerts from flooding us.
+				 */
+				if ((now + 60) < nexttime) nexttime = now + 60;
+			}
 		}
 	}
 
