@@ -8,7 +8,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: do_rrd.c 7060 2012-07-14 16:32:11Z storner $";
+static char rcsid[] = "$Id: do_rrd.c 7304 2013-08-25 14:03:44Z storner $";
 
 #include <sys/types.h>
 #include <sys/time.h>
@@ -39,6 +39,7 @@ extern int seq;	/* from xymond_rrd.c */
 
 char *rrddir = NULL;
 int use_rrd_cache = 1;         /* Use the cache by default */
+int no_rrd = 0;                /* Write to rrd by default */
 
 static int  processorfd = 0;
 static FILE *processorstream = NULL;
@@ -269,7 +270,7 @@ static int create_and_update_rrd(char *hostname, char *testname, char *classname
 	xtreePos_t handle;
 	updcacheitem_t *cacheitem = NULL;
 	int pollinterval;
-	char *modifymsg;
+	strbuffer_t *modifymsg;
 	time_t updtime = 0;
 
 	/* Reset the RRD poll interval */
@@ -440,7 +441,7 @@ static int create_and_update_rrd(char *hostname, char *testname, char *classname
 	 * Match the RRD data against any DS client-configuration modifiers.
 	 */
 	modifymsg = check_rrdds_thresholds(hostname, classname, pagepaths, rrdfn, ((rrdtpldata_t *)template)->dsnames, rrdvalues);
-	if (modifymsg) sendmessage(modifymsg, NULL, XYMON_TIMEOUT, NULL);
+	if (modifymsg) combo_add(modifymsg);
 
 	/*
 	 * See if we want the data to go to an external handler.
@@ -459,6 +460,9 @@ static int create_and_update_rrd(char *hostname, char *testname, char *classname
 		}
 	}
 
+	/* Are we actually handling the writing of RRD files? */
+	if (no_rrd) return 0;
+
 	/* 
 	 * We cannot just cache data every time because then after CACHESZ updates
 	 * of each RRD, we will flush all of the data at once (all of the caches 
