@@ -13,7 +13,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymond_channel.c 7085 2012-07-16 11:08:37Z storner $";
+static char rcsid[] = "$Id: xymond_channel.c 7217 2013-07-25 16:04:40Z storner $";
 
 #include <sys/types.h>
 #include <sys/ipc.h>
@@ -38,13 +38,9 @@ static char rcsid[] = "$Id: xymond_channel.c 7085 2012-07-16 11:08:37Z storner $
 
 #include "libxymon.h"
 
-#include "xymond_ipc.h"
-
 #include <signal.h>
 
 
-#define MSGTIMEOUT 30	/* Seconds */
-
 
 /* Our in-memory queue of messages received from xymond via IPC. One queue per peer. */
 typedef struct xymon_msg_t {
@@ -78,6 +74,9 @@ typedef struct xymon_peer_t {
 
 void * peers;
 
+pid_t deadpid = 0;
+int childexit;
+
 xymond_channel_t *channel = NULL;
 char *logfn = NULL;
 int locatorbased = 0;
@@ -86,6 +85,7 @@ enum locator_servicetype_t locatorservice = ST_MAX;
 static int running = 1;
 static int gotalarm = 0;
 static int pendingcount = 0;
+static int messagetimeout = 30;
 
 /*
  * chksumsize is the space left in front of the message buffer, to
@@ -227,6 +227,8 @@ void openconnection(xymon_peer_t *peer)
 				putenv(logfnenv);
 			}
 
+			dbgprintf("Child '%s' started (PID %d), about to fork\n", peer->childcmd, (int)getpid());
+
 			n = dup2(pfd[0], STDIN_FILENO);
 			close(pfd[0]); close(pfd[1]);
 			n = execvp(peer->childcmd, peer->childargs);
@@ -399,8 +401,6 @@ void shutdownconnection(xymon_peer_t *peer)
 
 void sig_handler(int signum)
 {
-	int childexit;
-
 	switch (signum) {
 	  case SIGTERM:
 	  case SIGINT:
@@ -410,7 +410,7 @@ void sig_handler(int signum)
 
 	  case SIGCHLD:
 		/* Our worker child died. Avoid zombies. */
-		wait(&childexit);
+		deadpid = wait(&childexit);
 		break;
 
 	  case SIGALRM:
@@ -450,6 +450,10 @@ int main(int argc, char *argv[])
 			for (cnid = C_STATUS; (channelnames[cnid] && strcmp(channelnames[cnid], cn)); cnid++) ;
 			if (channelnames[cnid] == NULL) cnid = -1;
 		}
+		else if (argnmatch(argv[argi], "--msgtimeout")) {
+			char *p = strchr(argv[argi], '=');
+			messagetimeout = atoi(p+1);
+		}
 		else if (argnmatch(argv[argi], "--daemon")) {
 			daemonize = 1;
 		}
@@ -584,6 +588,16 @@ int main(int argc, char *argv[])
 		struct sembuf s;
 		int n;
 
+		if (deadpid != 0) {
+			char *cause = "Unknown";
+			int ecode = -1;
+
+			if (WIFEXITED(childexit)) { cause = "Exit status"; ecode = WEXITSTATUS(childexit); }
+			else if (WIFSIGNALED(childexit)) { cause = "Signal"; ecode = WTERMSIG(childexit); }
+			errprintf("Child process %d died: %s %d\n", deadpid, cause, ecode);
+			deadpid = 0;
+		}
+
 		s.sem_num = GOCLIENT; s.sem_op  = -1; s.sem_flg = ((pendingcount > 0) ? IPC_NOWAIT : 0);
 		n = semop(channel->semid, &s, 1);
 
@@ -704,7 +718,7 @@ int main(int argc, char *argv[])
 		for (handle = xtreeFirst(peers); (handle != xtreeEnd(peers)); handle = xtreeNext(peers, handle)) {
 			int canwrite = 1, hasfailed = 0;
 			xymon_peer_t *pwalk;
-			time_t msgtimeout = gettimer() - MSGTIMEOUT;
+			time_t msgtimeout = gettimer() - messagetimeout;
 			int flushcount = 0;
 
 			pwalk = (xymon_peer_t *) xtreeData(peers, handle);
