@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymond_client.c 7149 2012-08-01 16:16:57Z storner $";
+static char rcsid[] = "$Id: xymond_client.c 7252 2013-08-05 11:54:11Z storner $";
 
 #include <stdio.h>
 #include <string.h>
@@ -48,8 +48,11 @@ int sendclearfiles = 1;
 int sendclearports = 1;
 int sendclearsvcs = 1;
 int localmode     = 0;
+int unknownclientosok = 0;
 int noreportcolor = COL_CLEAR;
 
+int usebackfeedqueue = 0;
+
 typedef struct updinfo_t {
 	char *hostname;
 	time_t updtime;
@@ -1157,7 +1160,7 @@ void unix_procs_report(char *hostname, char *clientclass, enum ostype_t os,
 
 	freestrbuffer(monmsg);
 
-	if (anycountdata) sendmessage(STRBUF(countdata), NULL, XYMON_TIMEOUT, NULL);
+	if (anycountdata) combo_add(countdata);
 	clearstrbuffer(countdata);
 }
 
@@ -1514,7 +1517,7 @@ void file_report(char *hostname, char *clientclass, enum ostype_t os,
 		clearstrbuffer(greendata);
 	}
 
-	if (anyszdata) sendmessage(STRBUF(sizedata), NULL, XYMON_TIMEOUT, NULL);
+	if (anyszdata) combo_add(sizedata);
 	clearstrbuffer(sizedata);
 }
 
@@ -1556,7 +1559,7 @@ void linecount_report(char *hostname, char *clientclass, enum ostype_t os,
 		}
 	}
 
-	if (anydata) sendmessage(STRBUF(countdata), NULL, XYMON_TIMEOUT, NULL);
+	if (anydata) combo_add(countdata);
 	clearstrbuffer(countdata);
 }
 
@@ -1574,8 +1577,7 @@ void unix_netstat_report(char *hostname, char *clientclass, enum ostype_t os,
 	sprintf(msgline, "data %s.netstat\n%s\n", commafy(hostname), osname(os));
 	addtobuffer(msg, msgline);
 	addtobuffer(msg, netstatstr);
-	sendmessage(STRBUF(msg), NULL, XYMON_TIMEOUT, NULL);
-
+	combo_add(msg);
 	freestrbuffer(msg);
 }
 
@@ -1592,8 +1594,7 @@ void unix_ifstat_report(char *hostname, char *clientclass, enum ostype_t os,
 	sprintf(msgline, "data %s.ifstat\n%s\n", commafy(hostname), osname(os));
 	addtobuffer(msg, msgline);
 	addtobuffer(msg, ifstatstr);
-	sendmessage(STRBUF(msg), NULL, XYMON_TIMEOUT, NULL);
-
+	combo_add(msg);
 	freestrbuffer(msg);
 }
 
@@ -1619,8 +1620,7 @@ void unix_vmstat_report(char *hostname, char *clientclass, enum ostype_t os,
 	sprintf(msgline, "data %s.vmstat\n%s\n", commafy(hostname), osname(os));
 	addtobuffer(msg, msgline);
 	addtobuffer(msg, p+1);
-	sendmessage(STRBUF(msg), NULL, XYMON_TIMEOUT, NULL);
-
+	combo_add(msg);
 	freestrbuffer(msg);
 }
 
@@ -1746,7 +1746,7 @@ void unix_ports_report(char *hostname, char *clientclass, enum ostype_t os,
 		clearstrbuffer(monmsg);
 	}
 
-	if (anycountdata) sendmessage(STRBUF(countdata), NULL, XYMON_TIMEOUT, NULL);
+	if (anycountdata) combo_add(countdata);
 	clearstrbuffer(countdata);
 }
 
@@ -1769,6 +1769,7 @@ void unix_ports_report(char *hostname, char *clientclass, enum ostype_t os,
 #include "client/zos.c"
 #include "client/mqcollect.c"
 #include "client/snmpcollect.c"
+#include "client/generic.c"
 
 static volatile int reloadconfig = 0;
 
@@ -2074,6 +2075,9 @@ int main(int argc, char *argv[])
 				tok = strtok(NULL, ",");
 			}
 		}
+		else if (strcmp(argv[argi], "--unknownclientosok") == 0) {
+			unknownclientosok = 1;
+		}
 		else if (argnmatch(argv[argi], "--dump-config")) {
 			load_client_config(configfn);
 			dump_client_config();
@@ -2112,6 +2116,8 @@ int main(int argc, char *argv[])
 	updinfotree = xtreeNew(strcasecmp);
 	running = 1;
 
+	usebackfeedqueue = (sendmessage_init_local() > 0);
+
 	while (running) {
 		char *eoln, *restofmsg, *p;
 		char *metadata[MAX_META+1];
@@ -2180,7 +2186,7 @@ int main(int argc, char *argv[])
 			/* Check for duplicates */
 			if (add_updateinfo(hostname, seq, timestamp) != 0) continue;
 
-			combo_start();
+			if (usebackfeedqueue) combo_start_local(); else combo_start();
 			switch (os) {
                           case OS_FREEBSD:
                                 handle_freebsd_client(hostname, clientclass, os, hinfo, sender, timestamp, restofmsg);
@@ -2257,7 +2263,11 @@ int main(int argc, char *argv[])
 				break;
 
 			  default:
-                                errprintf("No client backend for OS '%s' sent by %s\n", clientos, sender);
+				if (unknownclientosok) {
+					dbgprintf("No client backend for OS '%s' sent by %s; using generic\n", clientos, sender);
+					handle_generic_client(hostname, clientclass, os, hinfo, sender, timestamp, restofmsg);
+				}
+				else errprintf("No client backend for OS '%s' sent by %s\n", clientos, sender);
                                 break;
 			}
 			combo_end();
@@ -2283,6 +2293,8 @@ int main(int argc, char *argv[])
 		}
 	}
 
+	if (usebackfeedqueue) sendmessage_finish_local();
+
 	return 0;
 }
 
