@@ -12,7 +12,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymond_rrd.c 7136 2012-08-01 08:51:24Z storner $";
+static char rcsid[] = "$Id: xymond_rrd.c 7323 2014-01-07 09:42:42Z storner $";
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -28,6 +28,7 @@ static char rcsid[] = "$Id: xymond_rrd.c 7136 2012-08-01 08:51:24Z storner $";
 #include <sys/un.h>
 #include <fcntl.h>
 #include <errno.h>
+#include <libgen.h>
 
 #include "libxymon.h"
 #include "xymond_worker.h"
@@ -44,6 +45,7 @@ static char rcsid[] = "$Id: xymond_rrd.c 7136 2012-08-01 08:51:24Z storner $";
 int seq = 0;
 static int running = 1;
 static time_t reloadtime = 0;
+static int reloadextprocessor = 0;
 
 typedef struct rrddeftree_t {
 	char *key;
@@ -58,6 +60,9 @@ static void sig_handler(int signum)
 	  case SIGHUP:
 		  reloadtime = 0;
 		  break;
+	  case SIGPIPE:
+		  reloadextprocessor = 0;
+		  break;
 	  case SIGCHLD:
 		  break;
 	  case SIGINT:
@@ -188,6 +193,7 @@ int main(int argc, char *argv[])
 	char *processor = NULL;
 	struct sockaddr_un ctlsockaddr;
 	int ctlsocket;
+	int usebackfeedqueue = 0;
 
 	/* Handle program options. */
 	for (argi = 1; (argi < argc); argi++) {
@@ -213,6 +219,9 @@ int main(int argc, char *argv[])
 		else if (strcmp(argv[argi], "--no-cache") == 0) {
 			use_rrd_cache = 0;
 		}
+		else if (strcmp(argv[argi], "--no-rrd") == 0) {
+			no_rrd = 1;
+		}
 		else if (net_worker_option(argv[argi])) {
 			/* Handled in the subroutine */
 		}
@@ -220,12 +229,16 @@ int main(int argc, char *argv[])
 
 	save_errbuf = 0;
 
+	if (no_rrd && !processor) errprintf("RRD writing disabled, but no external processor has been specified.\n");
+
 	if ((rrddir == NULL) && xgetenv("XYMONRRDS")) {
 		rrddir = strdup(xgetenv("XYMONRRDS"));
 	}
 
 	if (exthandler && extids) setup_exthandler(exthandler, extids);
 
+	usebackfeedqueue = (sendmessage_init_local() > 0);
+
 	/* Do the network stuff if needed */
 	net_worker_run(ST_RRD, LOC_STICKY, update_locator_hostdata);
 
@@ -236,7 +249,7 @@ int main(int argc, char *argv[])
 	sigaction(SIGCHLD, &sa, NULL);
 	sigaction(SIGTERM, &sa, NULL);
 	sigaction(SIGINT, &sa, NULL);
-	signal(SIGPIPE, SIG_DFL);
+	sigaction(SIGPIPE, &sa, NULL);
 
 	/* Setup the control socket that receives cache-flush commands */
 	memset(&ctlsockaddr, 0, sizeof(ctlsockaddr));
@@ -279,6 +292,13 @@ int main(int argc, char *argv[])
 		int gotcachectlmessage;
 		time_t now;
 
+		/* If we need to re-open our external processor, do so */
+		if (reloadextprocessor) {
+			shutdown_extprocessor(); // Just in case we got a PIPE, but the pipe needs to be cleaned up still
+			setup_extprocessor(processor);
+			reloadextprocessor = 0;
+		}
+
 		/* See if we have any cache-control messages pending */
 		do {
 			n = recv(ctlsocket, ctlbuf, sizeof(ctlbuf), 0);
@@ -319,6 +339,8 @@ int main(int argc, char *argv[])
 			restofmsg = eoln+1;
 		}
 
+		if (usebackfeedqueue) combo_start_local(); else combo_start();
+
 		/* Parse the meta-data */
 		metacount = 0; 
 		memset(&metadata, 0, sizeof(metadata));
@@ -329,7 +351,7 @@ int main(int argc, char *argv[])
 		}
 		metadata[metacount] = NULL;
 
-		if ((metacount >= 14) && (strncmp(metadata[0], "@@status", 8) == 0)) {
+		if ((metacount >= 14) && (strncmp(metadata[0], "@@status", 8) == 0) && restofmsg) {
 			/*
 			 * @@status|timestamp|sender|origin|hostname|testname|expiretime|color|testflags|\
 			 * prevcolor|changetime|ackexpiretime|ackmessage|disableexpiretime|disablemessage|\
@@ -342,6 +364,7 @@ int main(int argc, char *argv[])
 			  case COL_YELLOW:
 			  case COL_RED:
 			  case COL_BLUE: /* Blue is OK, because it only arrives here when an update is sent */
+			  case COL_CLEAR: /* Clear is OK, because it could still contain valid metric data */
 				tstamp = atoi(metadata[1]);
 				sender = metadata[2];
 				hostname = metadata[4]; 
@@ -353,11 +376,11 @@ int main(int argc, char *argv[])
 				break;
 
 			  default:
-				/* Ignore reports with purple, blue or clear - they have no data we want. */
+				/* Ignore reports with purple - they have no data we want. */
 				break;
 			}
 		}
-		else if ((metacount > 5) && (strncmp(metadata[0], "@@data", 6) == 0)) {
+		else if ((metacount > 5) && (strncmp(metadata[0], "@@data", 6) == 0) && restofmsg) {
 			/* @@data|timestamp|sender|origin|hostname|testname|classname|pagepaths */
 			tstamp = atoi(metadata[1]);
 			sender = metadata[2];
@@ -393,7 +416,7 @@ int main(int argc, char *argv[])
 
 			MEMDEFINE(hostdir);
 
-			sprintf(hostdir, "%s/%s", rrddir, hostname);
+			sprintf(hostdir, "%s/%s", rrddir, basename(hostname));
 			dropdirectory(hostdir, 1);
 
 			MEMUNDEFINE(hostdir);
@@ -428,6 +451,8 @@ int main(int argc, char *argv[])
 			/* Not implemented. See "droptest". */
 		}
 
+		combo_end();
+
 		/* 
 		 * We fork a subprocess when processing drophost requests.
 		 * Pickup any finished child processes to avoid zombies
@@ -447,6 +472,8 @@ int main(int argc, char *argv[])
 	close(ctlsocket);
 	unlink(ctlsockaddr.sun_path);
 
+	sendmessage_finish_local();
+
 	return 0;
 }
 
