@@ -10,7 +10,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: loaddata.c 7117 2012-07-24 15:48:41Z storner $";
+static char rcsid[] = "$Id: loaddata.c 7298 2013-08-24 06:27:33Z storner $";
 
 #include <limits.h>
 #include <stdio.h>
@@ -286,7 +286,7 @@ state_t *init_state(char *filename, logdata_t *log)
 		time_t fileage = (now - log->lastchange);
 
 		newstate->entry->color = log->color;
-		newstate->entry->testflags = strdup(log->testflags);
+		newstate->entry->testflags = strdup(log->testflags ? log->testflags : "");
 		if (testflag_set(newstate->entry, 'D')) newstate->entry->skin = dialupskin;
 		if (testflag_set(newstate->entry, 'R')) newstate->entry->skin = reverseskin;
 		newstate->entry->shorttext = strdup(log->msg);
@@ -486,6 +486,7 @@ state_t *load_state(dispsummary_t **sumhead)
 
 	if (!reportstart && !snapshot) {
 		char *dumpfn = getenv("BOARDDUMP");
+		char *filter = getenv("BOARDFILTER");
 
 		if (dumpfn) {
 			/* Debugging - read data from a dump file */
@@ -505,8 +506,13 @@ state_t *load_state(dispsummary_t **sumhead)
 			}
 		}
 		else {
-			xymondresult = sendmessage("xymondboard fields=hostname,testname,color,flags,lastchange,logtime,validtime,acktime,disabletime,sender,cookie,line1,acklist", NULL, XYMON_TIMEOUT, sres);
+			char *bcmd;
+
+			bcmd = (char *)malloc(1024 + (filter ? strlen(filter) : 0));
+			sprintf(bcmd, "xymondboard fields=hostname,testname,color,flags,lastchange,logtime,validtime,acktime,disabletime,sender,cookie,line1,acklist %s", (filter ? filter: ""));
+			xymondresult = sendmessage(bcmd, NULL, XYMON_TIMEOUT, sres);
 			board = getsendreturnstr(sres, 1);
+			xfree(bcmd);
 		}
 	}
 	else {
