@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: pagegen.c 7085 2012-07-16 11:08:37Z storner $";
+static char rcsid[] = "$Id: pagegen.c 7357 2014-01-19 21:49:42Z storner $";
 
 #include <limits.h>
 #include <stdio.h>
@@ -441,7 +441,7 @@ void do_hosts(host_t *head, int sorthosts, char *onlycols, char *exceptcols, FIL
 	col_list_t *groupcols, *gc;
 	int	genstatic;
 	int	columncount;
-	char	*xymonskin;
+	char	*xymonskin, *infocolumngif, *trendscolumngif;
 	int	rowcount = 0;
 	int     usetooltip = 0;
 
@@ -449,6 +449,8 @@ void do_hosts(host_t *head, int sorthosts, char *onlycols, char *exceptcols, FIL
 		return;
 
 	xymonskin = strdup(xgetenv("XYMONSKIN"));
+	infocolumngif = strdup(getenv("INFOCOLUMNGIF") ?  getenv("INFOCOLUMNGIF") : dotgiffilename(COL_GREEN, 0, 1));
+	trendscolumngif = strdup(getenv("TRENDSCOLUMNGIF") ?  getenv("TRENDSCOLUMNGIF") : dotgiffilename(COL_GREEN, 0, 1));
 
 	switch (tooltipuse) {
 	  case TT_STDONLY: usetooltip = (pagetype == PAGE_NORMAL); break;
@@ -553,10 +555,16 @@ void do_hosts(host_t *head, int sorthosts, char *onlycols, char *exceptcols, FIL
 				else if (reportstart == 0) {
 					/* Standard webpage */
 					char *skin;
+					char *img = dotgiffilename(e->color, e->acked, e->oldage);
 
 					if (strcmp(e->column->name, xgetenv("INFOCOLUMN")) == 0) {
 						/* Show the host IP on the hint display of the "info" column */
 						htmlalttag = alttag(e->column->name, COL_GREEN, 0, 1, h->ip);
+						img = infocolumngif;
+					}
+					else if (strcmp(e->column->name, xgetenv("TRENDSCOLUMN")) == 0) {
+						htmlalttag = alttag(e->column->name, COL_GREEN, 0, 1, h->ip);
+						img = trendscolumngif;
 					}
 					else {
 						htmlalttag = alttag(e->column->name, e->color, e->acked, e->propagate, e->age);
@@ -586,7 +594,7 @@ void do_hosts(host_t *head, int sorthosts, char *onlycols, char *exceptcols, FIL
 					}
 
 					fprintf(output, "<IMG SRC=\"%s/%s\" ALT=\"%s\" TITLE=\"%s\" HEIGHT=\"%s\" WIDTH=\"%s\" BORDER=0></A>",
-						skin, dotgiffilename(e->color, e->acked, e->oldage),
+						skin, img,
 						htmlalttag, htmlalttag,
 						xgetenv("DOTHEIGHT"), xgetenv("DOTWIDTH"));
 				}
@@ -679,6 +687,8 @@ void do_hosts(host_t *head, int sorthosts, char *onlycols, char *exceptcols, FIL
 	}
 
 	xfree(xymonskin);
+	xfree(infocolumngif);
+	xfree(trendscolumngif);
 }
 
 void do_groups(group_t *head, FILE *output, FILE *rssoutput, char *pagepath)
@@ -1102,7 +1112,7 @@ static void do_nongreenext(FILE *output, char *extenv, char *family)
 	xfree(extensions);
 }
 
-int do_nongreen_page(char *nssidebarfilename, int summarytype)
+int do_nongreen_page(char *nssidebarfilename, int summarytype, char *filenamebase)
 {
 	xymongen_page_t	nongreenpage;
 	FILE		*output = NULL;
@@ -1216,12 +1226,12 @@ int do_nongreen_page(char *nssidebarfilename, int summarytype)
 
 	switch (summarytype) {
 	  case PAGE_NONGREEN:
-		sprintf(filename, "nongreen%s", htmlextension);
-		sprintf(rssfilename, "nongreen%s", rssextension);
+		sprintf(filename, "%s%s", filenamebase, htmlextension);
+		sprintf(rssfilename, "%s%s", filenamebase, rssextension);
 		break;
 	  case PAGE_CRITICAL:
-		sprintf(filename, "critical%s", htmlextension);
-		sprintf(rssfilename, "critical%s", rssextension);
+		sprintf(filename, "%s%s", filenamebase, htmlextension);
+		sprintf(rssfilename, "%s%s", filenamebase, rssextension);
 		break;
 	}
 
