@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymongen.c 6752 2011-09-09 08:12:02Z storner $";
+static char rcsid[] = "$Id: xymongen.c 7311 2013-09-04 08:49:12Z storner $";
 
 #include <stdio.h>
 #include <unistd.h>
@@ -651,12 +651,15 @@ int main(int argc, char *argv[])
 
 	/* The full summary page - nongreen.html */
 	if (do_nongreen) {
-		nongreen_color = do_nongreen_page(nssidebarfilename, PAGE_NONGREEN);
+		nongreen_color = do_nongreen_page(nssidebarfilename, PAGE_NONGREEN, "nongreen");
+		nongreencolors = (nongreencolors & ~(1 << COL_YELLOW));
+		nongreencolors = (nongreencolors & ~(1 << COL_PURPLE));
+		nongreen_color = do_nongreen_page(nssidebarfilename, PAGE_NONGREEN, "red");
 		add_timestamp("Non-green page generation done");
 	}
 
 	/* Reduced summary (alerts) page - critical.html */
-	critical_color = do_nongreen_page(NULL, PAGE_CRITICAL);
+	critical_color = do_nongreen_page(NULL, PAGE_CRITICAL, "critical");
 	add_timestamp("Critical page generation done");
 
 	if (snapshot) {
@@ -683,16 +686,17 @@ int main(int argc, char *argv[])
 	if (egocolumn) {
 		char msgline[4096];
 		char *timestamps;
-		long tasksleep = (xgetenv("TASKSLEEP") ? atol(xgetenv("TASKSLEEP")) : 300);
-		int color;
+		long tasksleep = (xgetenv("TASKSLEEP") ? atol(xgetenv("TASKSLEEP")) : -1);
+		int usebackfeedqueue, color;
 
 		/* Go yellow if it runs for too long */
-		if (total_runtime() > tasksleep) {
+		if ((tasksleep > 0) && (total_runtime() > tasksleep)) {
 			errprintf("WARNING: Runtime %ld longer than TASKSLEEP (%ld)\n", total_runtime(), tasksleep);
 		}
 		color = (errbuf ? COL_YELLOW : COL_GREEN);
 
-		combo_start();
+		usebackfeedqueue = (sendmessage_init_local() > 0);
+		if (usebackfeedqueue) combo_start_local(); else combo_start();
 		init_status(color);
 		sprintf(msgline, "status %s.%s %s %s\n\n", xgetenv("MACHINE"), egocolumn, colorname(color), timestamp);
 		addtostatus(msgline);
@@ -743,6 +747,7 @@ int main(int argc, char *argv[])
 
 		finish_status();
 		combo_end();
+		if (usebackfeedqueue) sendmessage_finish_local();
 	}
 	else show_timestamps(NULL);
 
