@@ -10,7 +10,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: contest.c 7122 2012-07-26 07:16:29Z storner $";
+static char rcsid[] = "$Id: contest.c 7345 2014-01-10 09:29:38Z storner $";
 
 #include "config.h"
 
@@ -65,10 +65,11 @@ static tcptest_t *thead = NULL;
 
 int shuffletests = 0;
 int sslincludecipherlist = 1;
+int snienabled = 0;	/* SNI disabled by default */
 
 static svcinfo_t svcinfo_http  = { "http", NULL, 0, NULL, 0, 0, (TCP_GET_BANNER|TCP_HTTP), 80 };
 static svcinfo_t svcinfo_https = { "https", NULL, 0, NULL, 0, 0, (TCP_GET_BANNER|TCP_HTTP|TCP_SSL), 443 };
-static ssloptions_t default_sslopt = { NULL, SSLVERSION_DEFAULT };
+static ssloptions_t default_sslopt = { NULL, SSLVERSION_DEFAULT, NULL };
 
 static time_t sslcert_expiretime(char *timestr)
 {
@@ -571,6 +572,11 @@ static void setup_ssl(tcptest_t *item)
 			}
 		}
 
+
+#if (SSLEAY_VERSION_NUMBER >= 0x00908070)
+		if (item->sni) SSL_set_tlsext_host_name(item->ssldata, item->sni);
+#endif
+
 		/* SSL setup is done. Now attach the socket FD to the SSL protocol handler */
 		if (SSL_set_fd(item->ssldata, item->fd) != 1) {
 			char sslerrmsg[256];
@@ -962,12 +968,12 @@ void do_tcp_tests(int timeout, int concurrency)
 						   case EADDRINUSE   : errprintf("connect returned EADDRINUSE!\n"); break;
 						   case EFAULT       : errprintf("connect returned EFAULT!\n"); break;
 						   case EALREADY     : errprintf("connect returned EALREADY!\n"); break;
-						   default           : errprintf("connect returned %d, errno=%d\n", res, errno);
+						   default           : errprintf("connect returned %d for test %s, errno=%d, %s\n", res, nextinqueue->tspec, errno, strerror(errno));
 						}
 					}
 					else {
 						/* Should NEVER happen. connect returns 0 or -1 */
-						errprintf("Strange result from connect: %d, errno=%d\n", res, errno);
+						errprintf("Strange result from connect: %d, for test %s, errno=%d, %s\n", res, nextinqueue->tspec, errno, strerror(errno));
 					}
 				}
 				else {
