@@ -54,6 +54,7 @@ extern char *ciphersmedium;
 extern unsigned int warnbytesread;
 extern int shuffletests;
 extern int sslincludecipherlist;
+extern int snienabled;
 
 #define SSLVERSION_DEFAULT 0
 #define SSLVERSION_V2      1
@@ -108,6 +109,7 @@ typedef struct tcptest_t {
 
 	/* For testing SSL-wrapped services */
 	ssloptions_t *ssloptions;	/* Specific SSL options requested by user */
+	char *sni;
 	SSL_CTX *sslctx;		/* SSL context pointer */
 	SSL  *ssldata;			/* SSL data (socket) pointer */
 	char *certinfo;			/* Certificate info (subject+expiretime) */
