@@ -10,7 +10,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: httptest.c 7123 2012-07-26 07:17:02Z storner $";
+static char rcsid[] = "$Id: httptest.c 7345 2014-01-10 09:29:38Z storner $";
 
 #include <sys/types.h>
 #include <limits.h>
@@ -341,6 +341,7 @@ void add_http_test(testitem_t *t)
 	int firstcookie = 1;
 	char *decodedurl;
 	strbuffer_t *httprequest = newstrbuffer(0);
+	void *hinfo = NULL;
 
 	/* Allocate the private data and initialize it */
 	httptest = (http_data_t *) calloc(1, sizeof(http_data_t));
@@ -352,6 +353,9 @@ void add_http_test(testitem_t *t)
 		return;
 	}
 
+	hinfo = hostinfo(t->host->hostname);
+
+
 	httptest->url = strdup(decodedurl);
 	httptest->contlen = -1;
 	httptest->parsestatus = (httptest->weburl.proxyurl ? httptest->weburl.proxyurl->parseerror : httptest->weburl.desturl->parseerror);
@@ -482,6 +486,7 @@ void add_http_test(testitem_t *t)
 	if (httptest->weburl.desturl->schemeopts) {
 		if      (strstr(httptest->weburl.desturl->schemeopts, "3"))      sslopt_version = SSLVERSION_V3;
 		else if (strstr(httptest->weburl.desturl->schemeopts, "2"))      sslopt_version = SSLVERSION_V2;
+		else if (strstr(httptest->weburl.desturl->schemeopts, "t"))      sslopt_version = SSLVERSION_TLS1;
 
 		if      (strstr(httptest->weburl.desturl->schemeopts, "h"))      sslopt_ciphers = ciphershigh;
 		else if (strstr(httptest->weburl.desturl->schemeopts, "m"))      sslopt_ciphers = ciphersmedium;
@@ -578,10 +583,8 @@ void add_http_test(testitem_t *t)
 	}
 	{
 		char useragent[100];
-		void *hinfo;
 		char *browser = NULL;
 
-		hinfo = hostinfo(t->host->hostname);
 		if (hinfo) browser = xmh_item(hinfo, XMH_BROWSER);
 
 		if (browser) {
@@ -633,7 +636,15 @@ void add_http_test(testitem_t *t)
 
 	/* Some standard stuff */
 	addtobuffer(httprequest, "Accept: */*\r\n");
-	addtobuffer(httprequest, "Pragma: no-cache\r\n");
+	switch (httpversion) {
+	   case HTTPVER_10: 
+		addtobuffer(httprequest, "Pragma: no-cache\r\n");
+		break;
+	   case HTTPVER_11: 
+		addtobuffer(httprequest, "Cache-control: no-cache\r\n");
+		break;
+	}
+
 
 	if ((httptest->weburl.testtype == WEBTEST_SOAP) || (httptest->weburl.testtype == WEBTEST_NOSOAP)) {
 		/* Must provide a SOAPAction header */
@@ -673,5 +684,12 @@ void add_http_test(testitem_t *t)
 						 t->testspec, t->silenttest, grabstrbuffer(httprequest), 
 						 httptest, tcp_http_data_callback, tcp_http_final_callback);
 	}
+
+	if (hinfo && xmh_item(hinfo, XMH_FLAG_SNI))
+		httptest->tcptest->sni = httptest->weburl.desturl->host;
+	else if (hinfo && xmh_item(hinfo, XMH_FLAG_NOSNI))
+		httptest->tcptest->sni = NULL;
+	else
+		httptest->tcptest->sni = (snienabled ? httptest->weburl.desturl->host : NULL);
 }
 
