@@ -8,7 +8,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: xymonnet.c 7085 2012-07-16 11:08:37Z storner $";
+static char rcsid[] = "$Id: xymonnet.c 7345 2014-01-10 09:29:38Z storner $";
 
 #include <limits.h>
 #include <stdio.h>
@@ -1985,6 +1985,7 @@ int main(int argc, char *argv[])
 	int runtimewarn;		/* 300 = default TASKSLEEP setting */
 	int servicedumponly = 0;
 	int pingrunning = 0;
+	int usebackfeedqueue = 0;
 
 	if (init_ldap_library() != 0) {
 		errprintf("Failed to initialize ldap library\n");
@@ -2153,6 +2154,10 @@ int main(int argc, char *argv[])
 			char *p = strchr(argv[argi], '=');
 			p++; sslminkeysize = atoi(p);
 		}
+		else if (argnmatch(argv[argi], "--sni=")) {
+			char *p = strchr(argv[argi], '=');
+			p++; snienabled = ( (strcasecmp(p, "yes") == 0) || (strcasecmp(p, "on") == 0) || (strcasecmp(p, "enabled") == 0) || (strcasecmp(p, "true") == 0) || (strcasecmp(p, "1") == 0) );
+		}
 		else if (strcmp(argv[argi], "--no-cipherlist") == 0) {
 			sslincludecipherlist = 0;
 		}
@@ -2292,6 +2297,8 @@ int main(int argc, char *argv[])
 	if (pingcolumn) pingtest = add_service(pingcolumn, 0, 0, TOOL_FPING);
 	add_timestamp("Service definitions loaded");
 
+	usebackfeedqueue = (sendmessage_init_local() > 0);
+
 	load_tests();
 	add_timestamp(use_ares_lookup ? "Tests loaded" : "Tests loaded, hostname lookups done");
 
@@ -2339,7 +2346,12 @@ int main(int argc, char *argv[])
 		finish_ping_service(pingtest); 
 		sprintf(msg, "PING test completed (%d hosts)", pingcount);
 		add_timestamp(msg);
-		combo_start();
+
+		if (usebackfeedqueue)
+			combo_start_local();
+		else
+			combo_start();
+
 		send_results(pingtest, failgoesclear);
 		if (selectedhosts == 0) save_ping_status();
 		combo_end();
@@ -2441,7 +2453,11 @@ int main(int argc, char *argv[])
 		}
 	}
 
-	combo_start();
+	if (usebackfeedqueue)
+		combo_start_local();
+	else
+		combo_start();
+
 	for (handle = xtreeFirst(svctree); handle != xtreeEnd(svctree); handle = xtreeNext(svctree, handle)) {
 		s = (service_t *)xtreeData(svctree, handle);
 		switch (s->toolid) {
@@ -2464,13 +2480,14 @@ int main(int argc, char *argv[])
 	}
 	for (handle = xtreeFirst(testhosttree); (handle != xtreeEnd(testhosttree)); handle = xtreeNext(testhosttree, handle)) {
 		h = (testedhost_t *)xtreeData(testhosttree, handle);
-		send_http_results(httptest, h, h->firsthttp, nonetpage, failgoesclear);
+		send_http_results(httptest, h, h->firsthttp, nonetpage, failgoesclear, usebackfeedqueue);
 		send_content_results(httptest, h, nonetpage, contenttestname, failgoesclear);
 		send_ldap_results(ldaptest, h, nonetpage, failgoesclear);
 		if (ssltestname && !h->nosslcert) send_sslcert_status(h);
 	}
 
 	combo_end();
+
 	add_timestamp("Test results transmitted");
 
 	/*
@@ -2513,13 +2530,13 @@ int main(int argc, char *argv[])
 		int color;
 
 		/* Go yellow if it runs for too long */
-		if (total_runtime() > runtimewarn) {
+		if ((runtimewarn > 0) && (total_runtime() > runtimewarn)) {
 			errprintf("WARNING: Runtime %ld longer than time limit (%ld)\n", total_runtime(), runtimewarn);
 		}
 		color = (errbuf ? COL_YELLOW : COL_GREEN);
 		if (bigfailure) color = COL_RED;
 
-		combo_start();
+		if (usebackfeedqueue) combo_start_local(); else combo_start();
 		init_status(color);
 		sprintf(msgline, "status+%d %s.%s %s %s\n\n", validity, xgetenv("MACHINE"), egocolumn, colorname(color), timestamp);
 		addtostatus(msgline);
@@ -2561,6 +2578,8 @@ int main(int argc, char *argv[])
 
 	if (dnsfaillog) fclose(dnsfaillog);
 
+	if (usebackfeedqueue) sendmessage_finish_local();
+
 	return 0;
 }
 
